@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -69,6 +69,8 @@ void FollowUpReminderManager::load(bool forceReloadConfig)
                 } else {
                     delete info;
                 }
+            } else {
+                delete info;
             }
         } else {
             delete info;
