@@ -22,18 +22,18 @@
 
 #include "ui_collectionaclpage.h"
 
-#include <akonadi/collectionpropertiespage.h>
+#include <AkonadiWidgets/collectionpropertiespage.h>
 
 class CollectionAclPage : public Akonadi::CollectionPropertiesPage
 {
-  Q_OBJECT
-  public:
-    explicit CollectionAclPage( QWidget *parent = 0 );
+    Q_OBJECT
+public:
+    explicit CollectionAclPage(QWidget *parent = Q_NULLPTR);
 
-    void load( const Akonadi::Collection & col );
-    void save( Akonadi::Collection & col );
+    void load(const Akonadi::Collection &col) Q_DECL_OVERRIDE;
+    void save(Akonadi::Collection &col) Q_DECL_OVERRIDE;
 
-  private:
+private:
     Ui::CollectionAclPage ui;
 };
 
