@@ -25,9 +25,10 @@
 #include "treenodevisitor.h"
 #include "treenode.h"
 
-namespace Akregator {
+namespace Akregator
+{
 
-bool TreeNodeVisitor::visit(TreeNode* node)
+bool TreeNodeVisitor::visit(TreeNode *node)
 {
     return node->accept(this);
 }
