@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -31,13 +31,16 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#if QT_VERSION >= 0x050600
+    app.setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
     KLocalizedString::setApplicationDomain("contactprintthemeeditor");
     KAboutData aboutData(QStringLiteral("contactprintthemeeditor"),
                          i18n("Contact Print Theme Editor"),
                          QStringLiteral(KDEPIM_VERSION),
                          i18n("Contact Print Theme Editor"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2015 contactprintthemeeditor authors"));
+                         i18n("Copyright © 2015-2016 contactprintthemeeditor authors"));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kaddressbook")));
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
