@@ -34,8 +34,8 @@
 
 #include <KTimeZone>
 #include <KLocalizedString>
-#include <kstandarddirs.h>
-#include <kio/netaccess.h>
+#include <KIO/StoredTransferJob>
+#include <KJobWidgets>
 #include <kfileitem.h>
 #include <KSharedConfig>
 #include <QTemporaryFile>
@@ -155,10 +155,10 @@ AlarmCalendar::AlarmCalendar(const QString& path, CalEvent::Type type)
             Q_ASSERT(false);   // invalid event type for a calendar
             break;
     }
-    mUrl.setPath(path);       // N.B. constructor mUrl(path) doesn't work with UNIX paths
+    mUrl = QUrl::fromUserInput(path, QString(), QUrl::AssumeLocalFile);
     QString icalPath = path;
     icalPath.replace(QStringLiteral("\\.vcs$"), QStringLiteral(".ics"));
-    mICalUrl.setPath(icalPath);
+    mICalUrl = QUrl::fromUserInput(icalPath, QString(), QUrl::AssumeLocalFile);
     mCalType = (path == icalPath) ? LOCAL_ICAL : LOCAL_VCAL;    // is the calendar in ICal or VCal format?
 }
 
@@ -191,7 +191,7 @@ bool AlarmCalendar::open()
         if (!mUrl.isValid())
             return false;
 
-        qCDebug(KALARM_LOG) << mUrl.prettyUrl();
+        qCDebug(KALARM_LOG) << mUrl.toDisplayString();
         if (!mCalendarStorage)
         {
             MemoryCalendar::Ptr calendar(new MemoryCalendar(Preferences::timeZone(true)));
@@ -200,8 +200,9 @@ bool AlarmCalendar::open()
 
         // Check for file's existence, assuming that it does exist when uncertain,
         // to avoid overwriting it.
-        if (!KIO::NetAccess::exists(mUrl, KIO::NetAccess::SourceSide, MainWindow::mainMainWindow())
-        ||  load() == 0)
+        auto statJob = KIO::stat(mUrl.url(), KIO::StatJob::SourceSide, 2);
+        KJobWidgets::setWindow(statJob, MainWindow::mainMainWindow());
+        if (!statJob->exec() ||  load() == 0)
         {
             // The calendar file doesn't yet exist, or it's zero length, so create a new one
             bool created = false;
@@ -243,30 +244,43 @@ int AlarmCalendar::load()
         if (!mCalendarStorage)
             return -2;
 
-        qCDebug(KALARM_LOG) << mUrl.prettyUrl();
-        QString tmpFile;
-        if (!KIO::NetAccess::download(mUrl, tmpFile, MainWindow::mainMainWindow()))
-        {
-            qCCritical(KALARM_LOG) << "Download failure";
-            KAMessageBox::error(MainWindow::mainMainWindow(),
-                                xi18nc("@info", "Cannot download calendar: <filename>%1</filename>", mUrl.prettyUrl()));
-            return -1;
+        QString filename;
+        qCDebug(KALARM_LOG) << mUrl.toDisplayString();
+        if (!mUrl.isLocalFile()) {
+            auto getJob = KIO::storedGet(mUrl.url());
+            KJobWidgets::setWindow(getJob, MainWindow::mainMainWindow());
+            if (!getJob->exec())
+            {
+                qCCritical(KALARM_LOG) << "Download failure";
+                KAMessageBox::error(MainWindow::mainMainWindow(),
+                                    xi18nc("@info", "Cannot download calendar: <filename>%1</filename>", mUrl.toDisplayString()));
+                return -1;
+            }
+            QTemporaryFile tmpFile;
+            tmpFile.setAutoRemove(false);
+            tmpFile.write(getJob->data());
+            qCDebug(KALARM_LOG) << "--- Downloaded to" << tmpFile.fileName();
+            filename = tmpFile.fileName();
+        } else {
+            filename = mUrl.toLocalFile();
         }
-        qCDebug(KALARM_LOG) << "--- Downloaded to" << tmpFile;
         mCalendarStorage->calendar()->setTimeSpec(Preferences::timeZone(true));
-        mCalendarStorage->setFileName(tmpFile);
+        mCalendarStorage->setFileName(filename);
         if (!mCalendarStorage->load())
         {
             // Check if the file is zero length
-            KIO::NetAccess::removeTempFile(tmpFile);
-            KIO::UDSEntry uds;
-            KIO::NetAccess::stat(mUrl, uds, MainWindow::mainMainWindow());
-            KFileItem fi(uds, mUrl);
-            if (!fi.size())
-                return 0;     // file is zero length
-            qCCritical(KALARM_LOG) << "Error loading calendar file '" << tmpFile <<"'";
+            if (mUrl.isLocalFile()) {
+                auto statJob = KIO::stat(KIO::upUrl(mUrl));
+                KJobWidgets::setWindow(statJob, MainWindow::mainMainWindow());
+                statJob->exec();
+                KFileItem fi(statJob->statResult(), mUrl);
+                if (!fi.size())
+                    return 0;     // file is zero length
+            }
+
+            qCCritical(KALARM_LOG) << "Error loading calendar file '" << filename <<"'";
             KAMessageBox::error(MainWindow::mainMainWindow(),
-                                xi18nc("@info", "<para>Error loading calendar:</para><para><filename>%1</filename></para><para>Please fix or delete the file.</para>", mUrl.prettyUrl()));
+                                xi18nc("@info", "<para>Error loading calendar:</para><para><filename>%1</filename></para><para>Please fix or delete the file.</para>", mUrl.toDisplayString()));
             // load() could have partially populated the calendar, so clear it out
             mCalendarStorage->calendar()->close();
             mCalendarStorage->calendar().clear();
@@ -275,8 +289,10 @@ int AlarmCalendar::load()
             return -1;
         }
         if (!mLocalFile.isEmpty())
-            KIO::NetAccess::removeTempFile(mLocalFile);   // removes it only if it IS a temporary file
-        mLocalFile = tmpFile;
+            if (mLocalFile.startsWith(QDir::tempPath())) {
+                QFile::remove(mLocalFile);
+            }
+        mLocalFile = filename;
         fix(mCalendarStorage);   // convert events to current KAlarm format for when calendar is saved
         updateDisplayKAEvents();
     }
@@ -294,7 +310,7 @@ bool AlarmCalendar::reload()
     if (!mCalendarStorage)
         return false;
     {
-        qCDebug(KALARM_LOG) << mUrl.prettyUrl();
+        qCDebug(KALARM_LOG) << mUrl.toDisplayString();
         close();
         return open();
     }
@@ -324,17 +340,21 @@ bool AlarmCalendar::saveCal(const QString& newFile)
         {
             qCCritical(KALARM_LOG) << "Saving" << saveFilename << "failed.";
             KAMessageBox::error(MainWindow::mainMainWindow(),
-                                xi18nc("@info", "Failed to save calendar to <filename>%1</filename>", mICalUrl.prettyUrl()));
+                                xi18nc("@info", "Failed to save calendar to <filename>%1</filename>", mICalUrl.toDisplayString()));
             return false;
         }
 
         if (!mICalUrl.isLocalFile())
         {
-            if (!KIO::NetAccess::upload(saveFilename, mICalUrl, MainWindow::mainMainWindow()))
+            QFile file(saveFilename);
+            file.open(QIODevice::ReadOnly);
+            auto putJob = KIO::storedPut(&file, mICalUrl.url(), -1);
+            KJobWidgets::setWindow(putJob, MainWindow::mainMainWindow());
+            if (!putJob->exec())
             {
                 qCCritical(KALARM_LOG) << saveFilename << "upload failed.";
                 KAMessageBox::error(MainWindow::mainMainWindow(),
-                                    xi18nc("@info", "Cannot upload calendar to <filename>%1</filename>", mICalUrl.prettyUrl()));
+                                    xi18nc("@info", "Cannot upload calendar to <filename>%1</filename>", mICalUrl.toDisplayString()));
                 return false;
             }
         }
@@ -361,7 +381,9 @@ void AlarmCalendar::close()
     {
         if (!mLocalFile.isEmpty())
         {
-            KIO::NetAccess::removeTempFile(mLocalFile);   // removes it only if it IS a temporary file
+            if (mLocalFile.startsWith(QDir::tempPath())) { // removes it only if it IS a temporary file
+                QFile::remove(mLocalFile);
+            }
             mLocalFile = QStringLiteral("");
         }
     }
@@ -571,8 +593,8 @@ void AlarmCalendar::slotEventsToBeRemoved(const AkonadiModel::EventList& events)
 bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
 {
     qCDebug(KALARM_LOG);
-    QUrl url = KFileDialog::getOpenUrl(KUrl("filedialog:///importalarms"),
-                                       QString::fromLatin1("*.vcs *.ics|%1").arg(i18nc("@info", "Calendar Files")), parent);
+    QUrl url = KFileDialog::getOpenUrl(QUrl(QStringLiteral("filedialog:///importalarms")),
+                                       QStringLiteral("*.vcs *.ics|%1").arg(i18nc("@info", "Calendar Files")), parent);
     if (url.isEmpty())
     {
         qCCritical(KALARM_LOG) << "Empty URL";
@@ -591,7 +613,7 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
     if (local)
     {
         filename = url.toLocalFile();
-        if (!KStandardDirs::exists(filename))
+        if (!QFile::exists(filename))
         {
             qCDebug(KALARM_LOG) << "File '" << url.toDisplayString() <<"' not found";
             KAMessageBox::error(parent, xi18nc("@info", "Could not load calendar <filename>%1</filename>.", url.toDisplayString()));
@@ -600,12 +622,19 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
     }
     else
     {
-        if (!KIO::NetAccess::download(url, filename, MainWindow::mainMainWindow()))
+        auto getJob = KIO::storedGet(url.url());
+        KJobWidgets::setWindow(getJob, MainWindow::mainMainWindow());
+        if (!getJob->exec())
         {
             qCCritical(KALARM_LOG) << "Download failure";
             KAMessageBox::error(parent, xi18nc("@info", "Cannot download calendar: <filename>%1</filename>", url.toDisplayString()));
             return false;
         }
+        QTemporaryFile tmpFile;
+        tmpFile.setAutoRemove(false);
+        tmpFile.write(getJob->data());
+        tmpFile.seek(0);
+        filename = tmpFile.fileName();
         qCDebug(KALARM_LOG) << "--- Downloaded to" << filename;
     }
 
@@ -681,7 +710,7 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
 
     }
     if (!local)
-        KIO::NetAccess::removeTempFile(filename);
+        QFile::remove(filename);
     return success;
 }
 
@@ -695,33 +724,35 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
 bool AlarmCalendar::exportAlarms(const KAEvent::List& events, QWidget* parent)
 {
     bool append;
-    QString file = FileDialog::getSaveFileName(KUrl("kfiledialog:///exportalarms"),
-                                               QString::fromLatin1("*.ics|%1").arg(i18nc("@info", "Calendar Files")),
+    QString file = FileDialog::getSaveFileName(QUrl(QStringLiteral("kfiledialog:///exportalarms")),
+                                               QStringLiteral("*.ics|%1").arg(i18nc("@info", "Calendar Files")),
                                                parent, i18nc("@title:window", "Choose Export Calendar"),
                                                &append);
     if (file.isEmpty())
         return false;
-    KUrl url;
+    QUrl url;
     url.setPath(file);
     if (!url.isValid())
     {
         qCDebug(KALARM_LOG) << "Invalid URL";
         return false;
     }
-    qCDebug(KALARM_LOG) << url.prettyUrl();
+    qCDebug(KALARM_LOG) << url.toDisplayString();
 
     MemoryCalendar::Ptr calendar(new MemoryCalendar(Preferences::timeZone(true)));
     FileStorage::Ptr calStorage(new FileStorage(calendar, file));
     if (append  &&  !calStorage->load())
     {
         KIO::UDSEntry uds;
-        KIO::NetAccess::stat(url, uds, parent);
-        KFileItem fi(uds, url);
+        auto statJob = KIO::stat(url.url(), KIO::StatJob::SourceSide, 2);
+        KJobWidgets::setWindow(statJob, parent);
+        statJob->exec();
+        KFileItem fi(statJob->statResult(), url);
         if (fi.size())
         {
             qCCritical(KALARM_LOG) << "Error loading calendar file" << file << "for append";
             KAMessageBox::error(MainWindow::mainMainWindow(),
-                                xi18nc("@info", "Error loading calendar to append to:<nl/><filename>%1</filename>", url.prettyUrl()));
+                                xi18nc("@info", "Error loading calendar to append to:<nl/><filename>%1</filename>", url.toDisplayString()));
             return false;
         }
     }
@@ -761,15 +792,22 @@ bool AlarmCalendar::exportAlarms(const KAEvent::List& events, QWidget* parent)
         {
             qCCritical(KALARM_LOG) << file << ": failed";
             KAMessageBox::error(MainWindow::mainMainWindow(),
-                                xi18nc("@info", "Failed to save new calendar to:<nl/><filename>%1</filename>", url.prettyUrl()));
+                                xi18nc("@info", "Failed to save new calendar to:<nl/><filename>%1</filename>", url.toDisplayString()));
             success = false;
         }
-        else if (!local  &&  !KIO::NetAccess::upload(file, url, parent))
+        else if (!local)
         {
-            qCCritical(KALARM_LOG) << file << ": upload failed";
-            KAMessageBox::error(MainWindow::mainMainWindow(),
-                                xi18nc("@info", "Cannot upload new calendar to:<nl/><filename>%1</filename>", url.prettyUrl()));
-            success = false;
+            QFile qFile(file);
+            qFile.open(QIODevice::ReadOnly);
+            auto uploadJob = KIO::storedPut(&qFile, url.url(), -1);
+            KJobWidgets::setWindow(uploadJob, parent);
+            if (!uploadJob->exec())
+            {
+                qCCritical(KALARM_LOG) << file << ": upload failed";
+                KAMessageBox::error(MainWindow::mainMainWindow(),
+                                    xi18nc("@info", "Cannot upload new calendar to:<nl/><filename>%1</filename>", url.toDisplayString()));
+                success = false;
+            }
         }
         delete tempFile;
     }
