@@ -1,7 +1,7 @@
 /*
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2002 Don Sanders <sanders@kde.org>
-    Copyright (c) 2011-2015 Montel Laurent <montel@kde.org>
+    Copyright (c) 2011-2016 Montel Laurent <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License, version 2, as
@@ -52,6 +52,8 @@
 #include "util.h"
 #include "mailcommon/mailkernel.h"
 #include "MailCommon/FolderCollection"
+#include "messageviewer/headerstyleplugin.h"
+#include "messageviewer/headerstyle.h"
 
 #include <KActionCollection>
 #include <Akonadi/Contact/ContactSearchJob>
@@ -130,7 +132,7 @@ void KMReaderMainWin::showMessage(const QString &encoding, const Akonadi::Item &
 
     mParentCollection = parentCollection;
     mReaderWin->setOverrideEncoding(encoding);
-    mReaderWin->setMessage(msg, MessageViewer::Viewer::Force);
+    mReaderWin->setMessage(msg, MessageViewer::Force);
     KMime::Message::Ptr message = MessageCore::Util::message(msg);
     QString caption;
     if (message) {
@@ -149,6 +151,8 @@ void KMReaderMainWin::showMessage(const QString &encoding, const Akonadi::Item &
     const bool canChange = mParentCollection.isValid() ? (bool)(mParentCollection.rights() & Akonadi::Collection::CanDeleteItem) : false;
     mTrashAction->setEnabled(canChange);
 
+    mReaderWin->viewer()->headerStylePlugin()->headerStyle()->setReadOnlyMessage(!canChange);
+
     menuBar()->show();
     toolBar(QStringLiteral("mainToolBar"))->show();
 }
@@ -194,7 +198,30 @@ Akonadi::Collection KMReaderMainWin::parentCollection() const
     }
 }
 
-void KMReaderMainWin::slotTrashMsg()
+void KMReaderMainWin::slotExecuteMailAction(MessageViewer::Viewer::MailAction action)
+{
+    switch (action) {
+    case MessageViewer::Viewer::Trash:
+        slotTrashMessage();
+        break;
+    case MessageViewer::Viewer::Reply:
+        slotCustomReplyToMsg(QString());
+        break;
+    case MessageViewer::Viewer::ReplyToAll:
+        break;
+    case MessageViewer::Viewer::Forward:
+        slotRedirectMessage();
+        break;
+    case MessageViewer::Viewer::NewMessage:
+        break;
+    case MessageViewer::Viewer::Print:
+        break;
+    case MessageViewer::Viewer::PrintPreview:
+        break;
+    }
+}
+
+void KMReaderMainWin::slotTrashMessage()
 {
     if (!mMsg.isValid()) {
         return;
@@ -226,7 +253,7 @@ void KMReaderMainWin::slotForwardInlineMsg()
     command->start();
 }
 
-void KMReaderMainWin::slotForwardAttachedMsg()
+void KMReaderMainWin::slotForwardAttachedMessage()
 {
     if (!mReaderWin->message().hasPayload<KMime::Message::Ptr>()) {
         return;
@@ -249,23 +276,25 @@ void KMReaderMainWin::slotForwardAttachedMsg()
     command->start();
 }
 
-void KMReaderMainWin::slotRedirectMsg()
+void KMReaderMainWin::slotRedirectMessage()
 {
-    if (!mReaderWin->message().hasPayload<KMime::Message::Ptr>()) {
+    const Akonadi::Item currentItem  = mReaderWin->message();
+    if (!currentItem.hasPayload<KMime::Message::Ptr>()) {
         return;
     }
-    KMCommand *command = new KMRedirectCommand(this, mReaderWin->message());
+    KMCommand *command = new KMRedirectCommand(this, currentItem);
     connect(command, &KMTrashMsgCommand::completed, this, &KMReaderMainWin::slotReplyOrForwardFinished);
     command->start();
 }
 
 void KMReaderMainWin::slotCustomReplyToMsg(const QString &tmpl)
 {
-    if (!mReaderWin->message().hasPayload<KMime::Message::Ptr>()) {
+    const Akonadi::Item currentItem  = mReaderWin->message();
+    if (!currentItem.hasPayload<KMime::Message::Ptr>()) {
         return;
     }
     KMCommand *command = new KMReplyCommand(this,
-                                            mReaderWin->message(),
+                                            currentItem,
                                             MessageComposer::ReplySmart,
                                             mReaderWin->copyText(),
                                             false, tmpl);
@@ -275,11 +304,12 @@ void KMReaderMainWin::slotCustomReplyToMsg(const QString &tmpl)
 
 void KMReaderMainWin::slotCustomReplyAllToMsg(const QString &tmpl)
 {
-    if (!mReaderWin->message().hasPayload<KMime::Message::Ptr>()) {
+    const Akonadi::Item currentItem  = mReaderWin->message();
+    if (!currentItem.hasPayload<KMime::Message::Ptr>()) {
         return;
     }
     KMCommand *command = new KMReplyCommand(this,
-                                            mReaderWin->message(),
+                                            currentItem,
                                             MessageComposer::ReplyAll,
                                             mReaderWin->copyText(),
                                             false, tmpl);
@@ -290,11 +320,12 @@ void KMReaderMainWin::slotCustomReplyAllToMsg(const QString &tmpl)
 
 void KMReaderMainWin::slotCustomForwardMsg(const QString &tmpl)
 {
-    if (!mReaderWin->message().hasPayload<KMime::Message::Ptr>()) {
+    const Akonadi::Item currentItem  = mReaderWin->message();
+    if (!currentItem.hasPayload<KMime::Message::Ptr>()) {
         return;
     }
     KMCommand *command = new KMForwardCommand(this,
-            mReaderWin->message(),
+            currentItem,
             0, tmpl);
     connect(command, &KMTrashMsgCommand::completed, this, &KMReaderMainWin::slotReplyOrForwardFinished);
 
@@ -327,30 +358,21 @@ void KMReaderMainWin::setupAccel()
     KMail::Util::addQActionHelpText(mTrashAction, i18n("Move message to trashcan"));
     actionCollection()->addAction(QStringLiteral("move_to_trash"), mTrashAction);
     actionCollection()->setDefaultShortcut(mTrashAction, QKeySequence(Qt::Key_Delete));
-    connect(mTrashAction, &QAction::triggered, this, &KMReaderMainWin::slotTrashMsg);
+    connect(mTrashAction, &QAction::triggered, this, &KMReaderMainWin::slotTrashMessage);
 
     QAction *closeAction = KStandardAction::close(this, SLOT(close()), actionCollection());
     QList<QKeySequence> closeShortcut = closeAction->shortcuts();
     closeAction->setShortcuts(closeShortcut << QKeySequence(Qt::Key_Escape));
 
     //----- Message Menu
-
-    mFontAction = new KFontAction(i18n("Select Font"), this);
-    actionCollection()->addAction(QStringLiteral("text_font"), mFontAction);
-    mFontAction->setFont(mReaderWin->cssHelper()->bodyFont().family());
-    connect(mFontAction, static_cast<void (KFontAction::*)(const QString &)>(&KFontAction::triggered), this, &KMReaderMainWin::slotFontAction);
-    mFontSizeAction = new KFontSizeAction(i18n("Select Size"), this);
-    mFontSizeAction->setFontSize(mReaderWin->cssHelper()->bodyFont().pointSize());
-    actionCollection()->addAction(QStringLiteral("text_size"), mFontSizeAction);
-    connect(mFontSizeAction, &KFontSizeAction::fontSizeChanged, this, &KMReaderMainWin::slotSizeAction);
-
     connect(mReaderWin->viewer(), &MessageViewer::Viewer::popupMenu, this, &KMReaderMainWin::slotMessagePopup);
 
     connect(mReaderWin->viewer(), &MessageViewer::Viewer::itemRemoved, this, &QWidget::close);
 
     setStandardToolBarMenuEnabled(true);
     KStandardAction::configureToolbars(this, SLOT(slotEditToolbars()), actionCollection());
-    connect(mReaderWin->viewer(), &MessageViewer::Viewer::moveMessageToTrash, this, &KMReaderMainWin::slotTrashMsg);
+    connect(mReaderWin->viewer(), &MessageViewer::Viewer::moveMessageToTrash, this, &KMReaderMainWin::slotTrashMessage);
+    connect(mReaderWin->viewer(), &MessageViewer::Viewer::executeMailAction, this, &KMReaderMainWin::slotExecuteMailAction);
 }
 
 QAction *KMReaderMainWin::copyActionMenu(QMenu *menu)
@@ -506,10 +528,8 @@ void KMReaderMainWin::showMessagePopup(const Akonadi::Item &msg, const QUrl &url
             menu->addAction(mReaderWin->copyURLAction());
             menu->addSeparator();
             menu->addAction(mReaderWin->shareServiceUrlMenu());
-            if (mReaderWin->isAShortUrl(url)) {
-                menu->addSeparator();
-                menu->addAction(mReaderWin->expandShortUrlAction());
-            }
+            menu->addSeparator();
+            menu->addActions(mReaderWin->viewerPluginActionList(MessageViewer::ViewerPluginInterface::NeedUrl));
             if (!imageUrl.isEmpty()) {
                 menu->addSeparator();
                 menu->addAction(mReaderWin->copyImageLocation());
@@ -640,27 +660,6 @@ void KMReaderMainWin::showMessagePopup(const Akonadi::Item &msg, const QUrl &url
     }
 }
 
-void KMReaderMainWin::slotFontAction(const QString &font)
-{
-    QFont f(mReaderWin->cssHelper()->bodyFont());
-    f.setFamily(font);
-    changeFont(f);
-}
-
-void KMReaderMainWin::slotSizeAction(int size)
-{
-    QFont f(mReaderWin->cssHelper()->bodyFont());
-    f.setPointSize(size);
-    changeFont(f);
-}
-
-void KMReaderMainWin::changeFont(const QFont &f)
-{
-    mReaderWin->cssHelper()->setBodyFont(f);
-    mReaderWin->cssHelper()->setPrintFont(f);
-    mReaderWin->update();
-}
-
 void KMReaderMainWin::slotEditToolbars()
 {
     KConfigGroup grp(KMKernel::self()->config(), "ReaderWindow");
