@@ -1,7 +1,7 @@
 /*
   This file is part of KMail, the KDE mail client.
   Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
-  Copyright (c) 2009-2015 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2016 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -622,10 +622,10 @@ QAction *KMReaderWin::downloadImageToDiskAction() const
 
 void KMReaderWin::clear(bool force)
 {
-    mViewer->clear(force ? Viewer::Force : Viewer::Delayed);
+    mViewer->clear(force ? Force : Delayed);
 }
 
-void KMReaderWin::setMessage(const Akonadi::Item &item, Viewer::UpdateMode updateMode)
+void KMReaderWin::setMessage(const Akonadi::Item &item, UpdateMode updateMode)
 {
     qCDebug(KMAIL_LOG) << Q_FUNC_INFO << parentWidget();
     mViewer->setMessageItem(item, updateMode);
@@ -648,7 +648,7 @@ QUrl KMReaderWin::imageUrlClicked() const
 
 void KMReaderWin::update(bool force)
 {
-    mViewer->update(force ? Viewer::Force : Viewer::Delayed);
+    mViewer->update(force ? Force : Delayed);
 }
 
 void KMReaderWin::slotUrlClicked(const Akonadi::Item &item, const QUrl &url)
@@ -709,9 +709,8 @@ bool KMReaderWin::printSelectedText(bool preview)
 void KMReaderWin::slotPrintComposeResult(KJob *job)
 {
     const bool preview = job->property("preview").toBool();
-    Q_ASSERT(dynamic_cast< ::MessageComposer::Composer * >(job));
-
     ::MessageComposer::Composer *composer = dynamic_cast< ::MessageComposer::Composer * >(job);
+    Q_ASSERT(composer);
     if (composer->error() == ::MessageComposer::Composer::NoError) {
 
         Q_ASSERT(composer->resultMessages().size() == 1);
@@ -837,13 +836,3 @@ void KMReaderWin::slotShareImage()
     KMCommand *command = new KMShareImageCommand(imageUrlClicked(), this);
     command->start();
 }
-
-bool KMReaderWin::isAShortUrl(const QUrl &url) const
-{
-    return mViewer->isAShortUrl(url);
-}
-
-QAction *KMReaderWin::expandShortUrlAction() const
-{
-    return mViewer->expandShortUrlAction();
-}
