@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -39,7 +39,7 @@ ImportBlogiloJob::~ImportBlogiloJob()
 
 void ImportBlogiloJob::start()
 {
-    Q_EMIT title(i18n("Start import Blogilo settings..."));
+    Q_EMIT title(i18n("Starting to import Blogilo settings..."));
     createProgressDialog(i18n("Import Blogilo settings"));
     mArchiveDirectory = archive()->directory();
     initializeListStep();
