@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -71,7 +71,7 @@ void ImportNotesJob::slotNextStep()
 
 void ImportNotesJob::start()
 {
-    Q_EMIT title(i18n("Start import KNotes settings..."));
+    Q_EMIT title(i18n("Starting to import KNotes settings..."));
     mArchiveDirectory = archive()->directory();
     // FIXME search archive ? searchAllFiles(mArchiveDirectory, QString());
     createProgressDialog(i18n("Import KNotes settings"));
